@@ -9,7 +9,7 @@ const Permutator = require('./Permutator');
 const NQuads = require('./NQuads');
 const util = require('./util');
 
-const POSITIONS = {'subject': 's', 'object': 'o', 'graph': 'g'};
+const POSITIONS = {subject: 's', object: 'o', graph: 'g'};
 
 module.exports = class URDNA2015Sync {
   constructor() {
@@ -68,7 +68,7 @@ module.exports = class URDNA2015Sync {
 
       // 5.3) For each blank node identifier identifier in non-normalized
       // identifiers:
-      for(let id in nonNormalized) {
+      for(const id in nonNormalized) {
         // 5.3.1) Create a hash, hash, according to the Hash First Degree
         // Quads algorithm.
         const hash = self.hashFirstDegreeQuads(id);
@@ -159,7 +159,7 @@ module.exports = class URDNA2015Sync {
         // using the Issue Identifier algorithm, passing canonical
         // issuer and existing identifier.
         const result = hashPathList[j];
-        for(let existing in result.issuer.existing) {
+        for(const existing in result.issuer.existing) {
           self.canonicalIssuer.getId(existing);
         }
       }
@@ -412,7 +412,7 @@ module.exports = class URDNA2015Sync {
 
     // 6) Return issuer and the hash that results from passing data to hash
     // through the hash algorithm.
-    return {hash: md.digest(), issuer: issuer};
+    return {hash: md.digest(), issuer};
   }
 
   // helper for modifying component during Hash First Degree Quads
@@ -448,7 +448,7 @@ module.exports = class URDNA2015Sync {
       // and graph name and it is a blank node that is not identified by
       // identifier:
       const quad = quads[i];
-      for(let key in quad) {
+      for(const key in quad) {
         const component = quad[key];
         if(key === 'predicate' ||
           !(component.termType === 'BlankNode' && component.value !== id)) {
@@ -479,7 +479,7 @@ module.exports = class URDNA2015Sync {
 
   // helper that iterates over quad components (skips predicate)
   forEachComponent(quad, op) {
-    for(let key in quad) {
+    for(const key in quad) {
       // skip `predicate`
       if(key === 'predicate') {
         continue;
